emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/modus-vivendi-theme f66e923 09/73: Tentative review of


From: Stefan Monnier
Subject: [elpa] externals/modus-vivendi-theme f66e923 09/73: Tentative review of intense paren match
Date: Wed, 26 Aug 2020 09:20:52 -0400 (EDT)

branch: externals/modus-vivendi-theme
commit f66e923d7947a4f6fa8535b3f2a151b745e25691
Author: Protesilaos Stavrou <info@protesilaos.com>
Commit: Protesilaos Stavrou <info@protesilaos.com>

    Tentative review of intense paren match
    
    This concerns the option for using an intense colour to highlight the
    matching parenthesis.  The rightmost column in the following tables
    shows how the "intense" values are more normalised than their standard
    counterparts.
    
    THIS IS SUBJECT TO FURTHER REVIEW, as the default colours will likely
    need to be adjusted as well.
    
    This is discussed in issue 70:
    https://gitlab.com/protesilaos/modus-themes/-/issues/70
    
    Relative colour luminance
    =========================
    
    These tables measure 'bg-paren-match' (default) and
    'bg-paren-match-intense' (optional) against relevant colours.  A full
    report will be published on my website and documented in the commit
    logs, README, CHANGELOG once we are done with the review.
    
    Modus Operandi
    --------------
    
    | Colour name        |         | #efcabf | #a0772f |
    |--------------------+---------+---------+---------|
    | fg-main            | #000000 |   13.87 |    5.17 |
    | bg-main            | #ffffff |    1.51 |    4.06 |
    | bg-alt             | #f0f0f0 |    1.33 |    3.56 |
    | bg-dim             | #f8f8f8 |    1.43 |    3.82 |
    | bg-region          | #bcbcbc |    1.25 |    2.14 |
    | red-nuanced-bg     | #fff1f0 |    1.38 |    3.69 |
    | green-nuanced-bg   | #ecf7ed |    1.38 |    3.69 |
    | yellow-nuanced-bg  | #fff3da |    1.38 |    3.69 |
    | blue-nuanced-bg    | #f3f3ff |    1.38 |    3.69 |
    | magenta-nuanced-bg | #fdf0ff |    1.38 |    3.69 |
    | cyan-nuanced-bg    | #ebf6fa |    1.38 |    3.69 |
    
    Modus Vivendi
    -------------
    
    | Colour name        |         | #6e3a50 | #93632f |
    |--------------------+---------+---------+---------|
    | fg-main            | #ffffff |    8.81 |    5.16 |
    | bg-main            | #000000 |    2.38 |    4.07 |
    | bg-alt             | #181a20 |    1.97 |    3.37 |
    | bg-dim             | #110b11 |    2.21 |    3.77 |
    | bg-region          | #3c3c3c |    1.25 |    2.14 |
    | red-nuanced-bg     | #2c0614 |    2.09 |    3.56 |
    | green-nuanced-bg   | #001904 |    2.09 |    3.56 |
    | yellow-nuanced-bg  | #221000 |    2.09 |    3.56 |
    | blue-nuanced-bg    | #0f0e39 |    2.09 |    3.56 |
    | magenta-nuanced-bg | #230631 |    2.09 |    3.56 |
    | cyan-nuanced-bg    | #041529 |    2.08 |    3.55 |
---
 modus-operandi-theme.el | 16 ++++++++++------
 modus-vivendi-theme.el  | 16 ++++++++++------
 2 files changed, 20 insertions(+), 12 deletions(-)

diff --git a/modus-operandi-theme.el b/modus-operandi-theme.el
index 105fce3..26318f9 100644
--- a/modus-operandi-theme.el
+++ b/modus-operandi-theme.el
@@ -607,7 +607,8 @@ more pronounced greyscale colour."
   "Conditional use of intense colours for matching parentheses.
 NORMALBG should the special palette colour 'bg-paren-match' or
 something similar.  INTENSEBG must be easier to discern next to
-other backgrounds."
+other backgrounds, such as the special palette colour
+'bg-paren-match-intense'."
   (if modus-operandi-theme-intense-paren-match
       (list :background intensebg)
     (list :background normalbg)))
@@ -858,9 +859,9 @@ AMOUNT is a customisation option."
       ;; can be combined with any of the "active" values, plus the
       ;; "special" and base foreground colours
       ;;
       ;; `bg-paren-match', `bg-region' and `bg-tab-active' must be
       ;; combined with `fg-main', while `bg-tab-inactive' should be
       ;; combined with `fg-dim'
       ;;
       ;; `bg-tab-bar' is only intended for the bar that holds the tabs and
       ;; can only be combined with `fg-main'
@@ -889,6 +890,7 @@ AMOUNT is a customisation option."
       ;; all pairs are combinable with themselves
       ("bg-hl-line" . "#f2eff3")
       ("bg-paren-match" . "#efcabf")
+      ("bg-paren-match-intense" . "#a0772f")
       ("bg-region" . "#bcbcbc")
 
       ("bg-tab-bar" . "#d5d5d5")
@@ -3350,7 +3352,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(sh-heredoc ((,class :foreground ,blue-alt)))
    `(sh-quoted-exec ((,class ,@(modus-operandi-theme-bold-weight) :foreground 
,magenta-alt)))
 ;;;;; show-paren-mode
-   `(show-paren-match ((,class ,@(modus-operandi-theme-paren bg-paren-match 
blue-intense-bg)
+   `(show-paren-match ((,class ,@(modus-operandi-theme-paren bg-paren-match
+                                                             
bg-paren-match-intense)
                                :foreground ,fg-main)))
    `(show-paren-match-expression ((,class :inherit modus-theme-special-calm)))
    `(show-paren-mismatch ((,class :inherit modus-theme-intense-red)))
@@ -3387,7 +3390,8 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; smartparens
    `(sp-pair-overlay-face ((,class :inherit modus-theme-special-warm)))
    `(sp-show-pair-enclosing ((,class :inherit modus-theme-special-mild)))
-   `(sp-show-pair-match-face ((,class ,@(modus-operandi-theme-paren 
bg-paren-match blue-intense-bg)
+   `(sp-show-pair-match-face ((,class ,@(modus-operandi-theme-paren 
bg-paren-match
+                                                                    
bg-paren-match-intense)
                                       :foreground ,fg-main)))
    `(sp-show-pair-mismatch-face ((,class :inherit modus-theme-intense-red)))
@@ -858,9 +859,9 @@ AMOUNT is a customisation option."
       ;; "special" and base foreground colours
       ;;
-      ;; `bg-paren-match', `bg-region' and `bg-tab-active' must be
-      ;; combined with `fg-main', while `bg-tab-inactive' should be
-      ;; combined with `fg-dim'
+      ;; `bg-paren-match', `bg-paren-match-intense', `bg-region' and
+      ;; `bg-tab-active' must be combined with `fg-main', while
+      ;; `bg-tab-inactive' should be combined with `fg-dim'
       ;;
       ;; `bg-tab-bar' is only intended for the bar that holds the tabs and
    `(sp-wrap-overlay-closing-pair ((,class :inherit sp-pair-overlay-face)))
diff --git a/modus-vivendi-theme.el b/modus-vivendi-theme.el
index 8e360da..2a65938 100644
--- a/modus-vivendi-theme.el
+++ b/modus-vivendi-theme.el
@@ -607,7 +607,8 @@ more pronounced greyscale colour."
   "Conditional use of intense colours for matching parentheses.
 NORMALBG should the special palette colour 'bg-paren-match' or
 something similar.  INTENSEBG must be easier to discern next to
-other backgrounds."
+other backgrounds, such as the special palette colour
+'bg-paren-match-intense'."
   (if modus-vivendi-theme-intense-paren-match
       (list :background intensebg)
     (list :background normalbg)))
@@ -858,9 +859,9 @@ AMOUNT is a customisation option."
       ;; can be combined with any of the "active" values, plus the
       ;; "special" and base foreground colours
       ;;
       ;; `bg-paren-match', `bg-region' and `bg-tab-active' must be
       ;; combined with `fg-main', while `bg-tab-inactive' should be
       ;; combined with `fg-dim'
       ;;
       ;; `bg-tab-bar' is only intended for the bar that holds the tabs and
       ;; can only be combined with `fg-main'
@@ -889,6 +890,7 @@ AMOUNT is a customisation option."
       ;; all pairs are combinable with themselves
       ("bg-hl-line" . "#151823")
       ("bg-paren-match" . "#6e3a50")
+      ("bg-paren-match-intense" . "#93632f")
       ("bg-region" . "#3c3c3c")
 
       ("bg-tab-bar" . "#2c2c2c")
@@ -3350,7 +3352,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(sh-heredoc ((,class :foreground ,blue-alt)))
    `(sh-quoted-exec ((,class ,@(modus-vivendi-theme-bold-weight) :foreground 
,magenta-alt)))
 ;;;;; show-paren-mode
-   `(show-paren-match ((,class ,@(modus-vivendi-theme-paren bg-paren-match 
blue-intense-bg)
+   `(show-paren-match ((,class ,@(modus-vivendi-theme-paren bg-paren-match
+                                                            
bg-paren-match-intense)
                                :foreground ,fg-main)))
    `(show-paren-match-expression ((,class :inherit modus-theme-special-calm)))
    `(show-paren-mismatch ((,class :inherit modus-theme-intense-red)))
@@ -3387,7 +3390,8 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; smartparens
    `(sp-pair-overlay-face ((,class :inherit modus-theme-special-warm)))
    `(sp-show-pair-enclosing ((,class :inherit modus-theme-special-mild)))
-   `(sp-show-pair-match-face ((,class ,@(modus-vivendi-theme-paren 
bg-paren-match blue-intense-bg)
+   `(sp-show-pair-match-face ((,class ,@(modus-vivendi-theme-paren 
bg-paren-match
+                                                                   
bg-paren-match-intense)
                                       :foreground ,fg-main)))
    `(sp-show-pair-mismatch-face ((,class :inherit modus-theme-intense-red)))
@@ -858,9 +859,9 @@ AMOUNT is a customisation option."
       ;; "special" and base foreground colours
       ;;
-      ;; `bg-paren-match', `bg-region' and `bg-tab-active' must be
-      ;; combined with `fg-main', while `bg-tab-inactive' should be
-      ;; combined with `fg-dim'
+      ;; `bg-paren-match', `bg-paren-match-intense', `bg-region' and
+      ;; `bg-tab-active' must be combined with `fg-main', while
+      ;; `bg-tab-inactive' should be combined with `fg-dim'
       ;;
       ;; `bg-tab-bar' is only intended for the bar that holds the tabs and
    `(sp-wrap-overlay-closing-pair ((,class :inherit sp-pair-overlay-face)))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]